@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2024 Google LLC
+# Copyright 2025 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,6 +14,9 @@
 # limitations under the License.
 #
 import inspect
+import json
+import logging as std_logging
+import pickle
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
 import warnings
 
@@ -23,14 +26,93 @@ from google.api_core import retry_async as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.protobuf import empty_pb2  # type: ignore
+from google.protobuf.json_format import MessageToJson
+import google.protobuf.message
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
+import proto  # type: ignore
 
 from google.cloud.binaryauthorization_v1.types import resources, service
 
 from .base import DEFAULT_CLIENT_INFO, BinauthzManagementServiceV1Transport
 from .grpc import BinauthzManagementServiceV1GrpcTransport
 
+try:
+    from google.api_core import client_logging  # type: ignore
+
+    CLIENT_LOGGING_SUPPORTED = True  # pragma: NO COVER
+except ImportError:  # pragma: NO COVER
+    CLIENT_LOGGING_SUPPORTED = False
+
+_LOGGER = std_logging.getLogger(__name__)
+
+
+class _LoggingClientAIOInterceptor(
+    grpc.aio.UnaryUnaryClientInterceptor
+):  # pragma: NO COVER
+    async def intercept_unary_unary(self, continuation, client_call_details, request):
+        logging_enabled = CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
+            std_logging.DEBUG
+        )
+        if logging_enabled:  # pragma: NO COVER
+            request_metadata = client_call_details.metadata
+            if isinstance(request, proto.Message):
+                request_payload = type(request).to_json(request)
+            elif isinstance(request, google.protobuf.message.Message):
+                request_payload = MessageToJson(request)
+            else:
+                request_payload = f"{type(request).__name__}: {pickle.dumps(request)}"
+
+            request_metadata = {
+                key: value.decode("utf-8") if isinstance(value, bytes) else value
+                for key, value in request_metadata
+            }
+            grpc_request = {
+                "payload": request_payload,
+                "requestMethod": "grpc",
+                "metadata": dict(request_metadata),
+            }
+            _LOGGER.debug(
+                f"Sending request for {client_call_details.method}",
+                extra={
+                    "serviceName": "google.cloud.binaryauthorization.v1.BinauthzManagementServiceV1",
+                    "rpcName": str(client_call_details.method),
+                    "request": grpc_request,
+                    "metadata": grpc_request["metadata"],
+                },
+            )
+        response = await continuation(client_call_details, request)
+        if logging_enabled:  # pragma: NO COVER
+            response_metadata = await response.trailing_metadata()
+            # Convert gRPC metadata `<class 'grpc.aio._metadata.Metadata'>` to list of tuples
+            metadata = (
+                dict([(k, str(v)) for k, v in response_metadata])
+                if response_metadata
+                else None
+            )
+            result = await response
+            if isinstance(result, proto.Message):
+                response_payload = type(result).to_json(result)
+            elif isinstance(result, google.protobuf.message.Message):
+                response_payload = MessageToJson(result)
+            else:
+                response_payload = f"{type(result).__name__}: {pickle.dumps(result)}"
+            grpc_response = {
+                "payload": response_payload,
+                "metadata": metadata,
+                "status": "OK",
+            }
+            _LOGGER.debug(
+                f"Received response to rpc {client_call_details.method}.",
+                extra={
+                    "serviceName": "google.cloud.binaryauthorization.v1.BinauthzManagementServiceV1",
+                    "rpcName": str(client_call_details.method),
+                    "response": grpc_response,
+                    "metadata": grpc_response["metadata"],
+                },
+            )
+        return response
+
 
 class BinauthzManagementServiceV1GrpcAsyncIOTransport(
     BinauthzManagementServiceV1Transport
@@ -235,10 +317,13 @@ class BinauthzManagementServiceV1GrpcAsyncIOTransport(
                 ],
             )
 
-        # Wrap messages. This must be done after self._grpc_channel exists
+        self._interceptor = _LoggingClientAIOInterceptor()
+        self._grpc_channel._unary_unary_interceptors.append(self._interceptor)
+        self._logged_channel = self._grpc_channel
         self._wrap_with_kind = (
             "kind" in inspect.signature(gapic_v1.method_async.wrap_method).parameters
         )
+        # Wrap messages. This must be done after self._logged_channel exists
         self._prep_wrapped_messages(client_info)
 
     @property
@@ -280,7 +365,7 @@ class BinauthzManagementServiceV1GrpcAsyncIOTransport(
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_policy" not in self._stubs:
-            self._stubs["get_policy"] = self.grpc_channel.unary_unary(
+            self._stubs["get_policy"] = self._logged_channel.unary_unary(
                 "/google.cloud.binaryauthorization.v1.BinauthzManagementServiceV1/GetPolicy",
                 request_serializer=service.GetPolicyRequest.serialize,
                 response_deserializer=resources.Policy.deserialize,
@@ -313,7 +398,7 @@ class BinauthzManagementServiceV1GrpcAsyncIOTransport(
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "update_policy" not in self._stubs:
-            self._stubs["update_policy"] = self.grpc_channel.unary_unary(
+            self._stubs["update_policy"] = self._logged_channel.unary_unary(
                 "/google.cloud.binaryauthorization.v1.BinauthzManagementServiceV1/UpdatePolicy",
                 request_serializer=service.UpdatePolicyRequest.serialize,
                 response_deserializer=resources.Policy.deserialize,
@@ -346,7 +431,7 @@ class BinauthzManagementServiceV1GrpcAsyncIOTransport(
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "create_attestor" not in self._stubs:
-            self._stubs["create_attestor"] = self.grpc_channel.unary_unary(
+            self._stubs["create_attestor"] = self._logged_channel.unary_unary(
                 "/google.cloud.binaryauthorization.v1.BinauthzManagementServiceV1/CreateAttestor",
                 request_serializer=service.CreateAttestorRequest.serialize,
                 response_deserializer=resources.Attestor.deserialize,
@@ -376,7 +461,7 @@ class BinauthzManagementServiceV1GrpcAsyncIOTransport(
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "get_attestor" not in self._stubs:
-            self._stubs["get_attestor"] = self.grpc_channel.unary_unary(
+            self._stubs["get_attestor"] = self._logged_channel.unary_unary(
                 "/google.cloud.binaryauthorization.v1.BinauthzManagementServiceV1/GetAttestor",
                 request_serializer=service.GetAttestorRequest.serialize,
                 response_deserializer=resources.Attestor.deserialize,
@@ -406,7 +491,7 @@ class BinauthzManagementServiceV1GrpcAsyncIOTransport(
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "update_attestor" not in self._stubs:
-            self._stubs["update_attestor"] = self.grpc_channel.unary_unary(
+            self._stubs["update_attestor"] = self._logged_channel.unary_unary(
                 "/google.cloud.binaryauthorization.v1.BinauthzManagementServiceV1/UpdateAttestor",
                 request_serializer=service.UpdateAttestorRequest.serialize,
                 response_deserializer=resources.Attestor.deserialize,
@@ -435,7 +520,7 @@ class BinauthzManagementServiceV1GrpcAsyncIOTransport(
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "list_attestors" not in self._stubs:
-            self._stubs["list_attestors"] = self.grpc_channel.unary_unary(
+            self._stubs["list_attestors"] = self._logged_channel.unary_unary(
                 "/google.cloud.binaryauthorization.v1.BinauthzManagementServiceV1/ListAttestors",
                 request_serializer=service.ListAttestorsRequest.serialize,
                 response_deserializer=service.ListAttestorsResponse.deserialize,
@@ -465,7 +550,7 @@ class BinauthzManagementServiceV1GrpcAsyncIOTransport(
         # gRPC handles serialization and deserialization, so we just need
         # to pass in the functions for each.
         if "delete_attestor" not in self._stubs:
-            self._stubs["delete_attestor"] = self.grpc_channel.unary_unary(
+            self._stubs["delete_attestor"] = self._logged_channel.unary_unary(
                 "/google.cloud.binaryauthorization.v1.BinauthzManagementServiceV1/DeleteAttestor",
                 request_serializer=service.DeleteAttestorRequest.serialize,
                 response_deserializer=empty_pb2.Empty.FromString,
@@ -578,7 +663,7 @@ class BinauthzManagementServiceV1GrpcAsyncIOTransport(
         return gapic_v1.method_async.wrap_method(func, *args, **kwargs)
 
     def close(self):
-        return self.grpc_channel.close()
+        return self._logged_channel.close()
 
     @property
     def kind(self) -> str:
