@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2024 Google LLC
+# Copyright 2025 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -24,6 +24,7 @@ from google.api_core import gapic_v1, rest_helpers, rest_streaming
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.requests import AuthorizedSession  # type: ignore
+import google.protobuf
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import json_format
 from requests import __version__ as requests_version
@@ -53,6 +54,9 @@ DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
     rest_version=f"requests@{requests_version}",
 )
 
+if hasattr(DEFAULT_CLIENT_INFO, "protobuf_runtime_version"):  # pragma: NO COVER
+    DEFAULT_CLIENT_INFO.protobuf_runtime_version = google.protobuf.__version__
+
 
 class BinauthzManagementServiceV1RestInterceptor:
     """Interceptor for BinauthzManagementServiceV1.
@@ -142,12 +146,35 @@ class BinauthzManagementServiceV1RestInterceptor:
     def post_create_attestor(self, response: resources.Attestor) -> resources.Attestor:
         """Post-rpc interceptor for create_attestor
 
-        Override in a subclass to manipulate the response
+        DEPRECATED. Please use the `post_create_attestor_with_metadata`
+        interceptor instead.
+
+        Override in a subclass to read or manipulate the response
         after it is returned by the BinauthzManagementServiceV1 server but before
-        it is returned to user code.
+        it is returned to user code. This `post_create_attestor` interceptor runs
+        before the `post_create_attestor_with_metadata` interceptor.
         """
         return response
 
+    def post_create_attestor_with_metadata(
+        self,
+        response: resources.Attestor,
+        metadata: Sequence[Tuple[str, Union[str, bytes]]],
+    ) -> Tuple[resources.Attestor, Sequence[Tuple[str, Union[str, bytes]]]]:
+        """Post-rpc interceptor for create_attestor
+
+        Override in a subclass to read or manipulate the response or metadata after it
+        is returned by the BinauthzManagementServiceV1 server but before it is returned to user code.
+
+        We recommend only using this `post_create_attestor_with_metadata`
+        interceptor in new development instead of the `post_create_attestor` interceptor.
+        When both interceptors are used, this `post_create_attestor_with_metadata` interceptor runs after the
+        `post_create_attestor` interceptor. The (possibly modified) response returned by
+        `post_create_attestor` will be passed to
+        `post_create_attestor_with_metadata`.
+        """
+        return response, metadata
+
     def pre_delete_attestor(
         self,
         request: service.DeleteAttestorRequest,
@@ -175,12 +202,35 @@ class BinauthzManagementServiceV1RestInterceptor:
     def post_get_attestor(self, response: resources.Attestor) -> resources.Attestor:
         """Post-rpc interceptor for get_attestor
 
-        Override in a subclass to manipulate the response
+        DEPRECATED. Please use the `post_get_attestor_with_metadata`
+        interceptor instead.
+
+        Override in a subclass to read or manipulate the response
         after it is returned by the BinauthzManagementServiceV1 server but before
-        it is returned to user code.
+        it is returned to user code. This `post_get_attestor` interceptor runs
+        before the `post_get_attestor_with_metadata` interceptor.
         """
         return response
 
+    def post_get_attestor_with_metadata(
+        self,
+        response: resources.Attestor,
+        metadata: Sequence[Tuple[str, Union[str, bytes]]],
+    ) -> Tuple[resources.Attestor, Sequence[Tuple[str, Union[str, bytes]]]]:
+        """Post-rpc interceptor for get_attestor
+
+        Override in a subclass to read or manipulate the response or metadata after it
+        is returned by the BinauthzManagementServiceV1 server but before it is returned to user code.
+
+        We recommend only using this `post_get_attestor_with_metadata`
+        interceptor in new development instead of the `post_get_attestor` interceptor.
+        When both interceptors are used, this `post_get_attestor_with_metadata` interceptor runs after the
+        `post_get_attestor` interceptor. The (possibly modified) response returned by
+        `post_get_attestor` will be passed to
+        `post_get_attestor_with_metadata`.
+        """
+        return response, metadata
+
     def pre_get_policy(
         self,
         request: service.GetPolicyRequest,
@@ -196,12 +246,35 @@ class BinauthzManagementServiceV1RestInterceptor:
     def post_get_policy(self, response: resources.Policy) -> resources.Policy:
         """Post-rpc interceptor for get_policy
 
-        Override in a subclass to manipulate the response
+        DEPRECATED. Please use the `post_get_policy_with_metadata`
+        interceptor instead.
+
+        Override in a subclass to read or manipulate the response
         after it is returned by the BinauthzManagementServiceV1 server but before
-        it is returned to user code.
+        it is returned to user code. This `post_get_policy` interceptor runs
+        before the `post_get_policy_with_metadata` interceptor.
         """
         return response
 
+    def post_get_policy_with_metadata(
+        self,
+        response: resources.Policy,
+        metadata: Sequence[Tuple[str, Union[str, bytes]]],
+    ) -> Tuple[resources.Policy, Sequence[Tuple[str, Union[str, bytes]]]]:
+        """Post-rpc interceptor for get_policy
+
+        Override in a subclass to read or manipulate the response or metadata after it
+        is returned by the BinauthzManagementServiceV1 server but before it is returned to user code.
+
+        We recommend only using this `post_get_policy_with_metadata`
+        interceptor in new development instead of the `post_get_policy` interceptor.
+        When both interceptors are used, this `post_get_policy_with_metadata` interceptor runs after the
+        `post_get_policy` interceptor. The (possibly modified) response returned by
+        `post_get_policy` will be passed to
+        `post_get_policy_with_metadata`.
+        """
+        return response, metadata
+
     def pre_list_attestors(
         self,
         request: service.ListAttestorsRequest,
@@ -219,12 +292,35 @@ class BinauthzManagementServiceV1RestInterceptor:
     ) -> service.ListAttestorsResponse:
         """Post-rpc interceptor for list_attestors
 
-        Override in a subclass to manipulate the response
+        DEPRECATED. Please use the `post_list_attestors_with_metadata`
+        interceptor instead.
+
+        Override in a subclass to read or manipulate the response
         after it is returned by the BinauthzManagementServiceV1 server but before
-        it is returned to user code.
+        it is returned to user code. This `post_list_attestors` interceptor runs
+        before the `post_list_attestors_with_metadata` interceptor.
         """
         return response
 
+    def post_list_attestors_with_metadata(
+        self,
+        response: service.ListAttestorsResponse,
+        metadata: Sequence[Tuple[str, Union[str, bytes]]],
+    ) -> Tuple[service.ListAttestorsResponse, Sequence[Tuple[str, Union[str, bytes]]]]:
+        """Post-rpc interceptor for list_attestors
+
+        Override in a subclass to read or manipulate the response or metadata after it
+        is returned by the BinauthzManagementServiceV1 server but before it is returned to user code.
+
+        We recommend only using this `post_list_attestors_with_metadata`
+        interceptor in new development instead of the `post_list_attestors` interceptor.
+        When both interceptors are used, this `post_list_attestors_with_metadata` interceptor runs after the
+        `post_list_attestors` interceptor. The (possibly modified) response returned by
+        `post_list_attestors` will be passed to
+        `post_list_attestors_with_metadata`.
+        """
+        return response, metadata
+
     def pre_update_attestor(
         self,
         request: service.UpdateAttestorRequest,
@@ -240,12 +336,35 @@ class BinauthzManagementServiceV1RestInterceptor:
     def post_update_attestor(self, response: resources.Attestor) -> resources.Attestor:
         """Post-rpc interceptor for update_attestor
 
-        Override in a subclass to manipulate the response
+        DEPRECATED. Please use the `post_update_attestor_with_metadata`
+        interceptor instead.
+
+        Override in a subclass to read or manipulate the response
         after it is returned by the BinauthzManagementServiceV1 server but before
-        it is returned to user code.
+        it is returned to user code. This `post_update_attestor` interceptor runs
+        before the `post_update_attestor_with_metadata` interceptor.
         """
         return response
 
+    def post_update_attestor_with_metadata(
+        self,
+        response: resources.Attestor,
+        metadata: Sequence[Tuple[str, Union[str, bytes]]],
+    ) -> Tuple[resources.Attestor, Sequence[Tuple[str, Union[str, bytes]]]]:
+        """Post-rpc interceptor for update_attestor
+
+        Override in a subclass to read or manipulate the response or metadata after it
+        is returned by the BinauthzManagementServiceV1 server but before it is returned to user code.
+
+        We recommend only using this `post_update_attestor_with_metadata`
+        interceptor in new development instead of the `post_update_attestor` interceptor.
+        When both interceptors are used, this `post_update_attestor_with_metadata` interceptor runs after the
+        `post_update_attestor` interceptor. The (possibly modified) response returned by
+        `post_update_attestor` will be passed to
+        `post_update_attestor_with_metadata`.
+        """
+        return response, metadata
+
     def pre_update_policy(
         self,
         request: service.UpdatePolicyRequest,
@@ -261,12 +380,35 @@ class BinauthzManagementServiceV1RestInterceptor:
     def post_update_policy(self, response: resources.Policy) -> resources.Policy:
         """Post-rpc interceptor for update_policy
 
-        Override in a subclass to manipulate the response
+        DEPRECATED. Please use the `post_update_policy_with_metadata`
+        interceptor instead.
+
+        Override in a subclass to read or manipulate the response
         after it is returned by the BinauthzManagementServiceV1 server but before
-        it is returned to user code.
+        it is returned to user code. This `post_update_policy` interceptor runs
+        before the `post_update_policy_with_metadata` interceptor.
         """
         return response
 
+    def post_update_policy_with_metadata(
+        self,
+        response: resources.Policy,
+        metadata: Sequence[Tuple[str, Union[str, bytes]]],
+    ) -> Tuple[resources.Policy, Sequence[Tuple[str, Union[str, bytes]]]]:
+        """Post-rpc interceptor for update_policy
+
+        Override in a subclass to read or manipulate the response or metadata after it
+        is returned by the BinauthzManagementServiceV1 server but before it is returned to user code.
+
+        We recommend only using this `post_update_policy_with_metadata`
+        interceptor in new development instead of the `post_update_policy` interceptor.
+        When both interceptors are used, this `post_update_policy_with_metadata` interceptor runs after the
+        `post_update_policy` interceptor. The (possibly modified) response returned by
+        `post_update_policy` will be passed to
+        `post_update_policy_with_metadata`.
+        """
+        return response, metadata
+
 
 @dataclasses.dataclass
 class BinauthzManagementServiceV1RestStub:
@@ -493,6 +635,10 @@ class BinauthzManagementServiceV1RestTransport(
             json_format.Parse(response.content, pb_resp, ignore_unknown_fields=True)
 
             resp = self._interceptor.post_create_attestor(resp)
+            response_metadata = [(k, str(v)) for k, v in response.headers.items()]
+            resp, _ = self._interceptor.post_create_attestor_with_metadata(
+                resp, response_metadata
+            )
             if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                 logging.DEBUG
             ):  # pragma: NO COVER
@@ -751,6 +897,10 @@ class BinauthzManagementServiceV1RestTransport(
             json_format.Parse(response.content, pb_resp, ignore_unknown_fields=True)
 
             resp = self._interceptor.post_get_attestor(resp)
+            response_metadata = [(k, str(v)) for k, v in response.headers.items()]
+            resp, _ = self._interceptor.post_get_attestor_with_metadata(
+                resp, response_metadata
+            )
             if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                 logging.DEBUG
             ):  # pragma: NO COVER
@@ -897,6 +1047,10 @@ class BinauthzManagementServiceV1RestTransport(
             json_format.Parse(response.content, pb_resp, ignore_unknown_fields=True)
 
             resp = self._interceptor.post_get_policy(resp)
+            response_metadata = [(k, str(v)) for k, v in response.headers.items()]
+            resp, _ = self._interceptor.post_get_policy_with_metadata(
+                resp, response_metadata
+            )
             if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                 logging.DEBUG
             ):  # pragma: NO COVER
@@ -1043,6 +1197,10 @@ class BinauthzManagementServiceV1RestTransport(
             json_format.Parse(response.content, pb_resp, ignore_unknown_fields=True)
 
             resp = self._interceptor.post_list_attestors(resp)
+            response_metadata = [(k, str(v)) for k, v in response.headers.items()]
+            resp, _ = self._interceptor.post_list_attestors_with_metadata(
+                resp, response_metadata
+            )
             if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                 logging.DEBUG
             ):  # pragma: NO COVER
@@ -1197,6 +1355,10 @@ class BinauthzManagementServiceV1RestTransport(
             json_format.Parse(response.content, pb_resp, ignore_unknown_fields=True)
 
             resp = self._interceptor.post_update_attestor(resp)
+            response_metadata = [(k, str(v)) for k, v in response.headers.items()]
+            resp, _ = self._interceptor.post_update_attestor_with_metadata(
+                resp, response_metadata
+            )
             if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                 logging.DEBUG
             ):  # pragma: NO COVER
@@ -1349,6 +1511,10 @@ class BinauthzManagementServiceV1RestTransport(
             json_format.Parse(response.content, pb_resp, ignore_unknown_fields=True)
 
             resp = self._interceptor.post_update_policy(resp)
+            response_metadata = [(k, str(v)) for k, v in response.headers.items()]
+            resp, _ = self._interceptor.post_update_policy_with_metadata(
+                resp, response_metadata
+            )
             if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                 logging.DEBUG
             ):  # pragma: NO COVER
