@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2024 Google LLC
+# Copyright 2025 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -24,6 +24,7 @@ from google.api_core import gapic_v1, rest_helpers, rest_streaming
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.requests import AuthorizedSession  # type: ignore
+import google.protobuf
 from google.protobuf import json_format
 from requests import __version__ as requests_version
 
@@ -52,6 +53,9 @@ DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
     rest_version=f"requests@{requests_version}",
 )
 
+if hasattr(DEFAULT_CLIENT_INFO, "protobuf_runtime_version"):  # pragma: NO COVER
+    DEFAULT_CLIENT_INFO.protobuf_runtime_version = google.protobuf.__version__
+
 
 class SystemPolicyV1RestInterceptor:
     """Interceptor for SystemPolicyV1.
@@ -97,12 +101,35 @@ class SystemPolicyV1RestInterceptor:
     def post_get_system_policy(self, response: resources.Policy) -> resources.Policy:
         """Post-rpc interceptor for get_system_policy
 
-        Override in a subclass to manipulate the response
+        DEPRECATED. Please use the `post_get_system_policy_with_metadata`
+        interceptor instead.
+
+        Override in a subclass to read or manipulate the response
         after it is returned by the SystemPolicyV1 server but before
-        it is returned to user code.
+        it is returned to user code. This `post_get_system_policy` interceptor runs
+        before the `post_get_system_policy_with_metadata` interceptor.
         """
         return response
 
+    def post_get_system_policy_with_metadata(
+        self,
+        response: resources.Policy,
+        metadata: Sequence[Tuple[str, Union[str, bytes]]],
+    ) -> Tuple[resources.Policy, Sequence[Tuple[str, Union[str, bytes]]]]:
+        """Post-rpc interceptor for get_system_policy
+
+        Override in a subclass to read or manipulate the response or metadata after it
+        is returned by the SystemPolicyV1 server but before it is returned to user code.
+
+        We recommend only using this `post_get_system_policy_with_metadata`
+        interceptor in new development instead of the `post_get_system_policy` interceptor.
+        When both interceptors are used, this `post_get_system_policy_with_metadata` interceptor runs after the
+        `post_get_system_policy` interceptor. The (possibly modified) response returned by
+        `post_get_system_policy` will be passed to
+        `post_get_system_policy_with_metadata`.
+        """
+        return response, metadata
+
 
 @dataclasses.dataclass
 class SystemPolicyV1RestStub:
@@ -312,6 +339,10 @@ class SystemPolicyV1RestTransport(_BaseSystemPolicyV1RestTransport):
             json_format.Parse(response.content, pb_resp, ignore_unknown_fields=True)
 
             resp = self._interceptor.post_get_system_policy(resp)
+            response_metadata = [(k, str(v)) for k, v in response.headers.items()]
+            resp, _ = self._interceptor.post_get_system_policy_with_metadata(
+                resp, response_metadata
+            )
             if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
                 logging.DEBUG
             ):  # pragma: NO COVER
